/*________________________________________________________

	File: Confidential.r

	Rez file for a printing extension that stamps a
	message on each page spooled.
	
	Dave Hersey
	Apple Developer Technical Support

	2/01/93  - dmh - Completely rewrote for the a5 seed.
	4/26/93  - dmh - Renamed files for b1 seed.
	4/27/93  - dmh - Updated NewSpoolPage override to work
					 w/o CopyDeepToShape.
	9/05/93  - dmh - Updated for b2.
			 - removed work-around for a 1.0a5
			   panel bug.  That should have been
			   removed in the b1 version  oops.
			 - Fixed minor bug with panel's editText
			   fields' highlighting.
			 - Switched to Exception.h assertion stuff
			   for error checking.
   12/18/93  - dmh - Updated for b3.
    2/22/94  - dmh - Updated for b4.
    5/03/94	 - dmh - Updated for f2.

	(Note: resource labels are in the Mark menu.)

__________________________________________________________*/

#include "SysTypes.r"
#include "Types.r"
#include "GXPrintingResEquates.r"
#include "GXPrintingResTypes.r"

#define kCreator				'CON!'

#define r_StampPanel			2000
#define r_StampPanelPict		100
#define r_StampPanelIcon		110

#define r_FinderBNDL			128
#define r_Str					200


// The default string and font size for stamping the page.

resource 'STR#' (r_Str, sysheap, purgeable)
{
	{
		"Confidential!",
		"80"
	}
};


/*=================== Print Dialog Panel Related Resources =================== */


/*======= Description of the panel resource added to print dialog by extension ======= */

resource gxPrintPanelType  (r_StampPanel, sysheap, purgeable)
{
		"Confidential", smRoman, r_StampPanelIcon, r_StampPanel
};


resource 'DITL' (r_StampPanel, sysheap, purgeable) {
	{
		/* [1] */
		{48, 102, 66, 146},
		RadioButton {
			enabled,
			"Off"
		},
		/* [2] */
		{48, 148, 66, 194},
		RadioButton {
			enabled,
			"On"
		},
		/* [3] */
		{48, 12, 64, 96},
		StaticText {
			disabled,
			"Page stamp:"
		},
		/* [4] */
		{83, 12, 99, 80},
		StaticText {
			disabled,
			"Message:"
		},
		/* [5] */
		{86, 85, 119, 323},
		EditText {
			enabled,
			""
		},
		/* [6] */
		{135, 12, 151, 82},
		StaticText {
			disabled,
			"Font size:"
		},
		/* [7] */
		{135, 85, 152, 114},
		EditText {
			enabled,
			""
		},
		/* [8] */
		{135, 118, 151, 142},
		StaticText {
			disabled,
			"pt."
		},
		/* [9] */
		{10, 127, 27, 227},
		StaticText {
			disabled,
			"Confidential"
		},
		/* [10] */
		{3, 305, 35, 336},
		Picture {
			disabled,
			r_StampPanelPict
		},
		/* [11] */
		{3, 4, 35, 36},
		Picture {
			disabled,
			r_StampPanelPict
		}
	}
};


/*======= 'xdtl' describing how to process the items in the Print Dialog Panel ======= */

resource 'xdtl' (r_StampPanel, sysheap, purgeable)
{
	{
				// "on/off" radio buttons (DITL items 1 & 2), stored in our
				// collection item (as an unsigned char) at offset 0:

		RadioButtons { kCreator, gxPrintingTagID, 0, {1,2} },


				// Message to print (DITL item 5), stored in our
				// collection item (as a Str63) at offset 6.  The
				// 0 means "don't select it":

		EditTextString { kCreator, gxPrintingTagID, 6, 5, 0 },


				// Font size to use (DITL item 7), stored in our
				// collection item (as a long) at offset 2.  The 0 means
				// "don't select it."  This item has a maximum value of
				// 200 and a minimum of 5:

		EditTextInteger { kCreator, gxPrintingTagID, 2, 7, 0, "5", "200" }
	};
};


/*=================== Required Printing Extension Types and Resources =================== */


/*======= Scope ('scop') Resource ======= */

/*	This resource tells the printing system which types
	of drivers we work with.  (We work with all of them.) */

resource gxExtensionScopeType (gxDriverScopeID, sysheap, purgeable)
{
	{
		gxAnyPrinterType		
	};
};


/*======= Message Override ('over') Resource ======= */

/*	This resource tells the printing system which messages we
	want to override and where the override code is located. */

resource gxOverrideType (gxExtensionUniversalOverrideID, sysheap, purgeable)
{
	{
		// message to override	segmentID		offset into JumpTable
		gxJobPrintDialog,			0, 					 4,
		gxHandlePanelEvent,			0, 					 8,
		gxSpoolPage,				0, 					12
	};
};


/*======= Extension Optimization ('eopt') Resource ======= */

/*	This resource tells the printing system at which times we'll
	be doing things so that it can optimize for us.		*/

resource gxExtensionOptimizationType (gxExtensionOptimizationID, sysheap, purgeable)
{
	gxDontExecuteDuringImaging,
	gxDontNeedDeviceStatus,
	gxDontChangePageAtGXDespoolPage,
	gxDontChangePageAtGXImagePage,
	gxDontChangePageAtGXRenderPage,
	gxNotServerPresenceRequired,
	gxNotClientPresenceRequired
};


/*======= Extension Load ('load') Resource ======= */

/*	This resource tells the printing system where we want
	to be loaded in the handler chain.  We'd liked to be
	last to execute so we can modify the final shape to
	be spooled out. Last to execute == first to load.	*/

resource gxExtensionLoadType (gxExtensionLoadID, sysheap, purgeable)
{
	gxExtensionLoadFirst
};


/*================== 'vers' resource that's required by all extensions ===================== */

/*	The first byte of this resource must be zero or one for
	this extension to be compatible with GX v1.0.  The
	remainder of the data is ignored.						*/

resource 'vers' (gxPrintingExtensionBaseID, sysheap, purgeable) {
	0x0,
	0x0,
	release,
	0x0,
	verUS,
	"",
	""
};


/*=================== Standard 'vers', bundle and icon resources follow =================== */

resource 'vers' (1, sysheap, purgeable) {
	0x1,
	0x0,
	final,
	0x0,
	verUS,
	"1.0",
	"1.0,  Apple Computer, Inc. 1992-1994"
};


resource 'vers' (2, sysheap, purgeable) {
	0x1,
	0x0,
	final,
	0x0,
	verUS,
	"1.0",
	"Confidential v1.0"
};


resource 'BNDL' (r_FinderBNDL, sysheap, purgeable) {
	kCreator,
	0,
	{
		'FREF',
		{
			0, r_FinderBNDL
		},
		'ICN#',
		{
			0, r_FinderBNDL
		}
	}
};


Type kCreator as 'STR ';

resource kCreator (0, "Owner resource", sysheap, purgeable) {
	"This is a printing extension that writes "
	"a message across a page during spooling."
};


resource 'FREF' (r_FinderBNDL, sysheap, purgeable) {
	gxPrintingExtensionType,
	0,
	""
};


resource 'PICT' (r_StampPanelPict, sysheap, purgeable) {
	2710,
	{0, 0, 32, 32},
	$"0011 02FF 0C00 FFFF FFFF 0000 0000 0000"
	$"0000 0020 0000 0020 0000 0000 0000 00A0"
	$"0082 0001 000A 0000 0000 0020 0020 0098"
	$"8020 0000 0000 0020 0020 0000 0000 0000"
	$"0000 0048 0000 0048 0000 0000 0008 0001"
	$"0008 0000 0000 00D2 C230 0000 0000 0000"
	$"0008 0000 00FF 0000 FFFF FFFF FFFF 0001"
	$"FFFF FFFF CCCC 0002 FFFF FFFF 9999 0003"
	$"FFFF FFFF 6666 0004 FFFF FFFF 3333 0005"
	$"FFFF FFFF 0000 0006 FFFF CCCC FFFF 0007"
	$"FFFF CCCC CCCC 0008 FFFF CCCC 9999 0009"
	$"FFFF CCCC 6666 000A FFFF CCCC 3333 000B"
	$"FFFF CCCC 0000 000C FFFF 9999 FFFF 000D"
	$"FFFF 9999 CCCC 000E FFFF 9999 9999 000F"
	$"FFFF 9999 6666 0010 FFFF 9999 3333 0011"
	$"FFFF 9999 0000 0012 FFFF 6666 FFFF 0013"
	$"FFFF 6666 CCCC 0014 FFFF 6666 9999 0015"
	$"FFFF 6666 6666 0016 FFFF 6666 3333 0017"
	$"FFFF 6666 0000 0018 FFFF 3333 FFFF 0019"
	$"FFFF 3333 CCCC 001A FFFF 3333 9999 001B"
	$"FFFF 3333 6666 001C FFFF 3333 3333 001D"
	$"FFFF 3333 0000 001E FFFF 0000 FFFF 001F"
	$"FFFF 0000 CCCC 0020 FFFF 0000 9999 0021"
	$"FFFF 0000 6666 0022 FFFF 0000 3333 0023"
	$"FFFF 0000 0000 0024 CCCC FFFF FFFF 0025"
	$"CCCC FFFF CCCC 0026 CCCC FFFF 9999 0027"
	$"CCCC FFFF 6666 0028 CCCC FFFF 3333 0029"
	$"CCCC FFFF 0000 002A CCCC CCCC FFFF 002B"
	$"CCCC CCCC CCCC 002C CCCC CCCC 9999 002D"
	$"CCCC CCCC 6666 002E CCCC CCCC 3333 002F"
	$"CCCC CCCC 0000 0030 CCCC 9999 FFFF 0031"
	$"CCCC 9999 CCCC 0032 CCCC 9999 9999 0033"
	$"CCCC 9999 6666 0034 CCCC 9999 3333 0035"
	$"CCCC 9999 0000 0036 CCCC 6666 FFFF 0037"
	$"CCCC 6666 CCCC 0038 CCCC 6666 9999 0039"
	$"CCCC 6666 6666 003A CCCC 6666 3333 003B"
	$"CCCC 6666 0000 003C CCCC 3333 FFFF 003D"
	$"CCCC 3333 CCCC 003E CCCC 3333 9999 003F"
	$"CCCC 3333 6666 0040 CCCC 3333 3333 0041"
	$"CCCC 3333 0000 0042 CCCC 0000 FFFF 0043"
	$"CCCC 0000 CCCC 0044 CCCC 0000 9999 0045"
	$"CCCC 0000 6666 0046 CCCC 0000 3333 0047"
	$"CCCC 0000 0000 0048 9999 FFFF FFFF 0049"
	$"9999 FFFF CCCC 004A 9999 FFFF 9999 004B"
	$"9999 FFFF 6666 004C 9999 FFFF 3333 004D"
	$"9999 FFFF 0000 004E 9999 CCCC FFFF 004F"
	$"9999 CCCC CCCC 0050 9999 CCCC 9999 0051"
	$"9999 CCCC 6666 0052 9999 CCCC 3333 0053"
	$"9999 CCCC 0000 0054 9999 9999 FFFF 0055"
	$"9999 9999 CCCC 0056 9999 9999 9999 0057"
	$"9999 9999 6666 0058 9999 9999 3333 0059"
	$"9999 9999 0000 005A 9999 6666 FFFF 005B"
	$"9999 6666 CCCC 005C 9999 6666 9999 005D"
	$"9999 6666 6666 005E 9999 6666 3333 005F"
	$"9999 6666 0000 0060 9999 3333 FFFF 0061"
	$"9999 3333 CCCC 0062 9999 3333 9999 0063"
	$"9999 3333 6666 0064 9999 3333 3333 0065"
	$"9999 3333 0000 0066 9999 0000 FFFF 0067"
	$"9999 0000 CCCC 0068 9999 0000 9999 0069"
	$"9999 0000 6666 006A 9999 0000 3333 006B"
	$"9999 0000 0000 006C 6666 FFFF FFFF 006D"
	$"6666 FFFF CCCC 006E 6666 FFFF 9999 006F"
	$"6666 FFFF 6666 0070 6666 FFFF 3333 0071"
	$"6666 FFFF 0000 0072 6666 CCCC FFFF 0073"
	$"6666 CCCC CCCC 0074 6666 CCCC 9999 0075"
	$"6666 CCCC 6666 0076 6666 CCCC 3333 0077"
	$"6666 CCCC 0000 0078 6666 9999 FFFF 0079"
	$"6666 9999 CCCC 007A 6666 9999 9999 007B"
	$"6666 9999 6666 007C 6666 9999 3333 007D"
	$"6666 9999 0000 007E 6666 6666 FFFF 007F"
	$"6666 6666 CCCC 0080 6666 6666 9999 0081"
	$"6666 6666 6666 0082 6666 6666 3333 0083"
	$"6666 6666 0000 0084 6666 3333 FFFF 0085"
	$"6666 3333 CCCC 0086 6666 3333 9999 0087"
	$"6666 3333 6666 0088 6666 3333 3333 0089"
	$"6666 3333 0000 008A 6666 0000 FFFF 008B"
	$"6666 0000 CCCC 008C 6666 0000 9999 008D"
	$"6666 0000 6666 008E 6666 0000 3333 008F"
	$"6666 0000 0000 0090 3333 FFFF FFFF 0091"
	$"3333 FFFF CCCC 0092 3333 FFFF 9999 0093"
	$"3333 FFFF 6666 0094 3333 FFFF 3333 0095"
	$"3333 FFFF 0000 0096 3333 CCCC FFFF 0097"
	$"3333 CCCC CCCC 0098 3333 CCCC 9999 0099"
	$"3333 CCCC 6666 009A 3333 CCCC 3333 009B"
	$"3333 CCCC 0000 009C 3333 9999 FFFF 009D"
	$"3333 9999 CCCC 009E 3333 9999 9999 009F"
	$"3333 9999 6666 00A0 3333 9999 3333 00A1"
	$"3333 9999 0000 00A2 3333 6666 FFFF 00A3"
	$"3333 6666 CCCC 00A4 3333 6666 9999 00A5"
	$"3333 6666 6666 00A6 3333 6666 3333 00A7"
	$"3333 6666 0000 00A8 3333 3333 FFFF 00A9"
	$"3333 3333 CCCC 00AA 3333 3333 9999 00AB"
	$"3333 3333 6666 00AC 3333 3333 3333 00AD"
	$"3333 3333 0000 00AE 3333 0000 FFFF 00AF"
	$"3333 0000 CCCC 00B0 3333 0000 9999 00B1"
	$"3333 0000 6666 00B2 3333 0000 3333 00B3"
	$"3333 0000 0000 00B4 0000 FFFF FFFF 00B5"
	$"0000 FFFF CCCC 00B6 0000 FFFF 9999 00B7"
	$"0000 FFFF 6666 00B8 0000 FFFF 3333 00B9"
	$"0000 FFFF 0000 00BA 0000 CCCC FFFF 00BB"
	$"0000 CCCC CCCC 00BC 0000 CCCC 9999 00BD"
	$"0000 CCCC 6666 00BE 0000 CCCC 3333 00BF"
	$"0000 CCCC 0000 00C0 0000 9999 FFFF 00C1"
	$"0000 9999 CCCC 00C2 0000 9999 9999 00C3"
	$"0000 9999 6666 00C4 0000 9999 3333 00C5"
	$"0000 9999 0000 00C6 0000 6666 FFFF 00C7"
	$"0000 6666 CCCC 00C8 0000 6666 9999 00C9"
	$"0000 6666 6666 00CA 0000 6666 3333 00CB"
	$"0000 6666 0000 00CC 0000 3333 FFFF 00CD"
	$"0000 3333 CCCC 00CE 0000 3333 9999 00CF"
	$"0000 3333 6666 00D0 0000 3333 3333 00D1"
	$"0000 3333 0000 00D2 0000 0000 FFFF 00D3"
	$"0000 0000 CCCC 00D4 0000 0000 9999 00D5"
	$"0000 0000 6666 00D6 0000 0000 3333 00D7"
	$"EEEE 0000 0000 00D8 DDDD 0000 0000 00D9"
	$"BBBB 0000 0000 00DA AAAA 0000 0000 00DB"
	$"8888 0000 0000 00DC 7777 0000 0000 00DD"
	$"5555 0000 0000 00DE 4444 0000 0000 00DF"
	$"2222 0000 0000 00E0 1111 0000 0000 00E1"
	$"0000 EEEE 0000 00E2 0000 DDDD 0000 00E3"
	$"0000 BBBB 0000 00E4 0000 AAAA 0000 00E5"
	$"0000 8888 0000 00E6 0000 7777 0000 00E7"
	$"0000 5555 0000 00E8 0000 4444 0000 00E9"
	$"0000 2222 0000 00EA 0000 1111 0000 00EB"
	$"0000 0000 EEEE 00EC 0000 0000 DDDD 00ED"
	$"0000 0000 BBBB 00EE 0000 0000 AAAA 00EF"
	$"0000 0000 8888 00F0 0000 0000 7777 00F1"
	$"0000 0000 5555 00F2 0000 0000 4444 00F3"
	$"0000 0000 2222 00F4 0000 0000 1111 00F5"
	$"EEEE EEEE EEEE 00F6 DDDD DDDD DDDD 00F7"
	$"BBBB BBBB BBBB 00F8 AAAA AAAA AAAA 00F9"
	$"8888 8888 8888 00FA 7777 7777 7777 00FB"
	$"5555 5555 5555 00FC 4444 4444 4444 00FD"
	$"2222 2222 2222 00FE 1111 1111 1111 00FF"
	$"0000 0000 0000 0000 0000 0020 0020 0000"
	$"0000 0020 0020 0000 02E1 0002 E100 06FD"
	$"00EC FFFA 000A FD00 00FF EE00 00FF FA00"
	$"0EFD 0000 FFF9 00FE FFF9 00FE FFFC 0014"
	$"FD00 00FF FA00 04FF F800 F8FF FA00 02FF"
	$"F5FF FC00 16FD 0000 FFFB 0001 FFF8 FEFF"
	$"01F8 FFFB 0002 FFF5 FFFC 0016 FD00 00FF"
	$"FB00 06FF 00F8 00F8 00FF FB00 02FF F5FF"
	$"FC00 16FD 0000 FFFB 0006 FFF8 00F8 00F8"
	$"FFFB 0002 FFF5 FFFC 0014 FD00 00FF FA00"
	$"04FF F800 F8FF FA00 02FF F5FF FC00 10FD"
	$"0000 FFF9 00FE FFF9 0002 FFF5 FFFC 0012"
	$"FD00 00FF F900 02FF 00FF F900 02FF F5FF"
	$"FC00 14FD 0000 FFFD 00FC FF00 00FC FFFD"
	$"0002 FFF5 FFFC 0018 FD00 00FF FE00 00FF"
	$"FD11 FEFF FD11 00FF FE00 02FF F5FF FC00"
	$"12FD 0003 FF00 00FF F411 05FF 0000 FFF5"
	$"FFFC 0010 FD00 02FF 0000 F2FF 0400 00FF"
	$"F5FF FC00 1CFD 0016 FF00 00FF F800 F800"
	$"F800 F800 F800 F800 F8FF 0000 FFF5 FFFC"
	$"001C FD00 16FF 0000 FF00 F800 F800 F800"
	$"F800 F800 F800 FF00 00FF F5FF FC00 1CFD"
	$"0016 FF00 00FF F800 F800 F800 F800 F800"
	$"F800 F8FF 0000 FFF5 FFFC 0010 FD00 00FF"
	$"FE00 F4FF FE00 02FF F5FF FC00 0CFD 0000"
	$"FFEE 0002 FFF5 FFFC 0010 FD00 00FF FD00"
	$"F8D7 FB00 02FF F5FF FC00 12FD 0000 FFFE"
	$"00F8 D701 0000 FBFF 01F5 FFFC 0011 FD00"
	$"00FF F300 00FF FE00 03FF F5F5 FFFC 0011"
	$"FD00 00FF F300 03FF 0000 FFFE F500 FFFC"
	$"0010 FD00 00FF F300 02FF 00FF FDF5 00FF"
	$"FC00 0FFD 0000 FFF3 0001 FFFF FCF5 00FF"
	$"FC00 0AFD 00F1 FFFB F500 FFFC 000A FA00"
	$"00FF EFF5 00FF FC00 06FA 00ED FFFC 0002"
	$"E100 02E1 0000 00A0 0083 00FF"
};


resource 'icl8' (r_FinderBNDL, sysheap, purgeable) {
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FF00 0000"
	$"FFF5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 FF00 0000"
	$"FFF5 F5F5 F5FF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFF5 F5F5 FF00 0000"
	$"FFF5 F5F5 F5FF 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 FFF5 F5F5 FF00 0000"
	$"FFF5 F5F5 F5FF 0000 0000 0000 00FF FFFF"
	$"0000 0000 0000 0000 FFFF FFF5 FF00 0000"
	$"FFF5 F5F5 F5FF 0000 0000 0000 FFF8 00F8"
	$"FF00 0000 0000 0000 FFF5 FFF5 FF00 0000"
	$"FFF5 F5F5 F5FF 0000 0000 00FF F8FF FFFF"
	$"F8FF 0000 0000 0000 FFF5 FFF5 FF00 0000"
	$"FFF5 F5F5 F5FF 0000 0000 00FF 00F8 00F8"
	$"00FF 0000 0000 0000 FFF5 FFF5 FF00 0000"
	$"FFF5 FFF5 F5FF 0000 0000 00FF F800 F800"
	$"F8FF 0000 0000 0000 FFF5 FFF5 FF00 0000"
	$"FFFF 00FF F5FF 0000 0000 0000 FFF8 00F8"
	$"FF00 0000 0000 0000 FFF5 FFF5 FF00 FF00"
	$"FF00 00FF F5FF 0000 0000 0000 00FF FFFF"
	$"0000 0000 0000 0000 FFF5 FFF5 FFFF F5FF"
	$"0000 00FF F5FF 0000 0000 0000 00FF 00FF"
	$"0000 0000 0000 0000 FFF5 FFF5 FFF5 F5FF"
	$"0000 00FF F5FF 0000 00FF FFFF FFFF 00FF"
	$"FFFF FFFF 0000 0000 FFF5 FFF5 F5F5 F5FF"
	$"0000 00FF F5FF 0000 FF11 1111 11FF FFFF"
	$"1111 1111 FF00 0000 FFF5 FFF5 F5F5 F5FF"
	$"0000 00FF F5FF 00FF 1111 1111 1111 1111"
	$"1111 1111 11FF 0000 FFF5 FFF5 F5F5 F5FF"
	$"0000 00FF F5FF 00FF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF 0000 FFF5 FFF5 F5F5 F5FF"
	$"0000 00FF F5FF 00FF F800 F800 F800 F800"
	$"F800 F800 F8FF 0000 FFF5 FFF5 F5F5 F5FF"
	$"0000 00FF F5FF 00FF 00F8 00F8 00F8 00F8"
	$"00F8 00F8 00FF 0000 FFF5 FFF5 F5F5 F5FF"
	$"0000 00FF F5FF 00FF F800 F800 F800 F800"
	$"F800 F800 F8FF 0000 FFF5 FFF5 F5F5 F5FF"
	$"0000 00FF F5FF 0000 FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FF00 0000 FFF5 FFF5 F5F5 F5FF"
	$"0000 00FF F5FF 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 FFF5 FFF5 FFF5 F5FF"
	$"FF00 00FF F5FF 0000 00D7 D7D7 D7D7 D7D7"
	$"D700 FFFF FFFF FFFF F5F5 FFF5 FFFF F5FF"
	$"FFFF 00FF F5FF 0000 D7D7 D7D7 D7D7 D7D7"
	$"0000 FF00 0000 FFF5 F5F5 FFF5 FF00 FF00"
	$"FFF5 FFF5 F5FF 0000 0000 0000 0000 0000"
	$"0000 FF00 00FF F5F5 F5F5 FFF5 FF00 0000"
	$"FFF5 F5F5 F5FF 0000 0000 0000 0000 0000"
	$"0000 FF00 FFF5 F5F5 F5F5 FFF5 FF00 0000"
	$"FFF5 F5F5 F5FF 0000 0000 0000 0000 0000"
	$"0000 FFFF F5F5 F5F5 F5F5 FFF5 FF00 0000"
	$"FFF5 F5F5 F5FF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFF5 F5F5 F5F5 F5F5 FFF5 FF00 0000"
	$"FFF5 F5F5 F5F5 F5FF F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 FFF5 FF00 0000"
	$"FFF5 F5F5 F5F5 F5FF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFF5 FF00 0000"
	$"FFF5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 FF00 0000"
	$"FFF5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 FF00 0000"
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF"
};


resource 'icl8' (r_StampPanelIcon, sysheap, purgeable) {
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FF00 0000 0000 0000"
	$"0000 0000 FF00 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 FF00 0000 0000 0000"
	$"0000 0000 FF00 0000 0000 0000 00FF FFFF"
	$"0000 0000 0000 0000 FFFF FF00 0000 0000"
	$"0000 0000 FF00 0000 0000 0000 FFF8 00F8"
	$"FF00 0000 0000 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 0000 0000 00FF F8FF FFFF"
	$"F8FF 0000 0000 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 0000 0000 00FF 00F8 00F8"
	$"00FF 0000 0000 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 0000 0000 00FF F800 F800"
	$"F8FF 0000 0000 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 0000 0000 0000 FFF8 00F8"
	$"FF00 0000 0000 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 0000 0000 0000 00FF FFFF"
	$"0000 0000 0000 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 0000 0000 0000 00FF 00FF"
	$"0000 0000 0000 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 0000 00FF FFFF FFFF 00FF"
	$"FFFF FFFF 0000 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 0000 FF11 1111 11FF FFFF"
	$"1111 1111 FF00 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 00FF 1111 1111 1111 1111"
	$"1111 1111 11FF 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 00FF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 00FF F800 F800 F800 F800"
	$"F800 F800 F8FF 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 00FF 00F8 00F8 00F8 00F8"
	$"00F8 00F8 00FF 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 00FF F800 F800 F800 F800"
	$"F800 F800 F8FF 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 0000 FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FF00 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 0000 00D7 D7D7 D7D7 D7D7"
	$"D7D7 0000 0000 0000 FFF5 FF00 0000 0000"
	$"0000 0000 FF00 0000 D7D7 D7D7 D7D7 D7D7"
	$"D700 00FF FFFF FFFF FFF5 FF00 0000 0000"
	$"0000 0000 FF00 0000 0000 0000 0000 0000"
	$"0000 00FF 0000 00FF F5F5 FF00 0000 0000"
	$"0000 0000 FF00 0000 0000 0000 0000 0000"
	$"0000 00FF 0000 FFF5 F5F5 FF00 0000 0000"
	$"0000 0000 FF00 0000 0000 0000 0000 0000"
	$"0000 00FF 00FF F5F5 F5F5 FF00 0000 0000"
	$"0000 0000 FF00 0000 0000 0000 0000 0000"
	$"0000 00FF FFF5 F5F5 F5F5 FF00 0000 0000"
	$"0000 0000 FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF F5F5 F5F5 F5F5 FF00 0000 0000"
	$"0000 0000 0000 00FF F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 FF00 0000 0000"
	$"0000 0000 0000 00FF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FF"
};


resource 'ICN#' (r_FinderBNDL, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"7FFF FFF8 8000 0008 87FF FF88 8400 0088"
		$"8407 00E8 8408 80A8 8417 40A8 8410 40A8"
		$"A410 40A8 D408 80AA 9407 00AD 1405 00A9"
		$"147D F0A1 1487 08A1 1500 04A1 15FF FCA1"
		$"1500 04A1 1500 04A1 1500 04A1 14FF F8A1"
		$"1400 00A9 947F BF2D D4FF 222A A400 2428"
		$"8400 2828 8400 3028 87FF E028 8100 0028"
		$"81FF FFE8 8000 0008 8000 0008 7FFF FFF0",
		/* [2] */
		$"7FFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8"
		$"FFFF FFF8 DFFF FFFA 9FFF FFFF 1FFF FFFF"
		$"1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF"
		$"1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF"
		$"1FFF FFFF 9FFF FFFF DFFF FFFA FFFF FFF8"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 7FFF FFF0"
	}
};


resource 'ICN#' (r_StampPanelIcon, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"0000 0000 0000 0000 0FFF FF80 0800 0080"
		$"0807 00E0 0808 80A0 0817 40A0 0810 40A0"
		$"0810 40A0 0808 80A0 0807 00A0 0805 00A0"
		$"087D F0A0 0887 08A0 0900 04A0 09FF FCA0"
		$"0900 04A0 0900 04A0 0900 04A0 08FF F8A0"
		$"0800 00A0 087F 80A0 08FF 1FA0 0800 1120"
		$"0800 1220 0800 1420 0800 1820 0FFF F020"
		$"0100 0020 01FF FFE0",
		/* [2] */
		$"0000 0000 0000 0000 0FFF FF80 0FFF FF80"
		$"0FFF FFE0 0FFF FFE0 0FFF FFE0 0FFF FFE0"
		$"0FFF FFE0 0FFF FFE0 0FFF FFE0 0FFF FFE0"
		$"0FFF FFE0 0FFF FFE0 0FFF FFE0 0FFF FFE0"
		$"0FFF FFE0 0FFF FFE0 0FFF FFE0 0FFF FFE0"
		$"0FFF FFE0 0FFF FFE0 0FFF FFE0 0FFF FFE0"
		$"0FFF FFE0 0FFF FFE0 0FFF FFE0 0FFF FFE0"
		$"01FF FFE0 01FF FFE0"
	}
};


resource 'ics#' (r_FinderBNDL, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"FFFE BFFE A186 A3C6 A346 E187 67E5 6FF5"
		$"6815 6FF5 E01F A796 BFFA BFFE 8002 FFFE",
		/* [2] */
		$"FFFE FFFE FFFE FFFE FFFE FFFF 7FFF 7FFF"
		$"7FFF 7FFF FFFF FFFE FFFE FFFE FFFE FFFE"
	}
};


resource 'ics#' (r_StampPanelIcon, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"7FFE 4002 4303 4783 4683 4303 4FC3 5FE3"
		$"5023 5FE3 4003 4F1F 4013 4017 7FFF 3FFF",
		/* [2] */
		$"7FFE 7FFE 7FFF 7FFF 7FFF 7FFF 7FFF 7FFF"
		$"7FFF 7FFF 7FFF 7FFF 7FFF 7FFF 7FFF 3FFF"
	}
};


resource 'ics8' (r_FinderBNDL, sysheap, purgeable) {
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FF00"
	$"FFF6 FFFF FFFF FFFF FFFF FFFF FFFF FF00"
	$"FF00 FF00 0000 00FF FF00 0000 00FF FF00"
	$"FFF6 FF00 0000 FFFF FFFF 0000 00FF FF00"
	$"FF00 FF00 0000 FFFF 00FF 0000 00FF FF00"
	$"FFFF FF00 0000 00FF FF00 0000 00FF FFFF"
	$"00FF FF00 00FF FFFF FFFF FF00 00FF F6FF"
	$"00FF FF00 FFFF FFFF FFFF FFFF 00FF 00FF"
	$"00FF FF00 FFF7 F7F7 F7F7 F7FF 00FF F6FF"
	$"00FF FF00 FFFF FFFF FFFF FFFF 00FF 00FF"
	$"FFFF FF00 0000 0000 0000 00FF FFFF FFFF"
	$"FFF6 FF00 00D7 D7D7 D700 00FF 00FF FF00"
	$"FF00 FFFF FFFF FFFF FFFF FFFF FF00 FF00"
	$"FFF6 FFFF FFFF FFFF FFFF FFFF FFFF FF00"
	$"FF00 F600 F600 F600 F600 F600 F600 FF00"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FF"
};


resource 'ics8' (r_StampPanelIcon, sysheap, purgeable) {
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FF00"
	$"00FF 0000 0000 0000 0000 0000 0000 FF00"
	$"00FF 0000 0000 FFFF 0000 0000 0000 FFFF"
	$"00FF 0000 00FF FFFF FF00 0000 0000 FFFF"
	$"00FF 0000 00FF FF00 FF00 0000 0000 FFFF"
	$"00FF 0000 0000 FFFF 0000 0000 0000 FFFF"
	$"00FF 0000 FFFF FFFF FFFF 0000 0000 FFFF"
	$"00FF 00FF FFFF FFFF FFFF FF00 0000 FFFF"
	$"00FF 00FF 0000 0000 0000 FF00 0000 FFFF"
	$"00FF 00FF FFFF FFFF FFFF FF00 0000 FFFF"
	$"00FF 0000 0000 0000 0000 0000 0000 FFFF"
	$"00FF 0000 D8D8 D8D8 0000 00FF FFFF FFFF"
	$"00FF 0000 0000 0000 0000 00FF 0000 FFFF"
	$"00FF 0000 0000 0000 0000 00FF 00FF FFFF"
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
};


resource 'icl4' (r_FinderBNDL, sysheap, purgeable) {
	$"0FFF FFFF FFFF FFFF FFFF FFFF FFFF F000"
	$"FC0C 0C0C 0C0C 0C0C 0C0C 0C0C 0C0C F000"
	$"F0C0 CFFF FFFF FFFF FFFF FFFF F0C0 F000"
	$"FC0C 0F00 0000 0000 0000 0000 FC0C F000"
	$"F0C0 CF00 0000 0FFF 0000 0000 FFF0 F000"
	$"FC0C 0F00 0000 FCCC F000 0000 FCFC F000"
	$"F0C0 CF00 000F CFFF CF00 0000 F0F0 F000"
	$"FC0C 0F00 000F CCCC CF00 0000 FCFC F000"
	$"F0F0 CF00 000F CCCC CF00 0000 F0F0 F000"
	$"FF0F 0F00 0000 FCCC F000 0000 FCFC F0F0"
	$"F00F CF00 0000 0FFF 0000 0000 F0F0 FFCF"
	$"000F 0F00 0000 0F0F 0000 0000 FCFC FC0F"
	$"000F CF00 0FFF FF0F FFFF 0000 F0F0 C0CF"
	$"000F 0F00 F222 2FFF 2222 F000 FCFC 0C0F"
	$"000F CF0F 2222 2222 2222 2F00 F0F0 C0CF"
	$"000F 0F0F FFFF FFFF FFFF FF00 FCFC 0C0F"
	$"000F CF0F CCCC CCCC CCCC CF00 F0F0 C0CF"
	$"000F 0F0F CCCC CCCC CCCC CF00 FCFC 0C0F"
	$"000F CF0F CCCC CCCC CCCC CF00 F0F0 C0CF"
	$"000F 0F00 FFFF FFFF FFFF F000 FCFC 0C0F"
	$"000F CF00 0000 0000 0000 0000 F0F0 F0CF"
	$"F00F 0F00 0333 3333 30FF FFFF 0CFC FF0F"
	$"FF0F CF00 3333 3333 00F0 00F0 C0F0 F0F0"
	$"FCFC 0F00 0000 0000 00F0 0F0C 0CFC F000"
	$"F0C0 CF00 0000 0000 00F0 F0C0 C0F0 F000"
	$"FC0C 0F00 0000 0000 00FF 0C0C 0CFC F000"
	$"F0C0 CFFF FFFF FFFF FFF0 C0C0 C0F0 F000"
	$"FC0C 0C0F 0C0C 0C0C 0C0C 0C0C 0CFC F000"
	$"F0C0 C0CF FFFF FFFF FFFF FFFF FFF0 F000"
	$"FC0C 0C0C 0C0C 0C0C 0C0C 0C0C 0C0C F000"
	$"F0C0 C0C0 C0C0 C0C0 C0C0 C0C0 C0C0 F000"
	$"0FFF FFFF FFFF FFFF FFFF FFFF FFFF"
};


resource 'icl4' (r_StampPanelIcon, sysheap, purgeable) {
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 FFFF FFFF FFFF FFFF FFFF F000 0000"
	$"0000 F000 0000 0000 0000 0000 F000 0000"
	$"0000 F000 0000 0FFF 0000 0000 FFF0 0000"
	$"0000 F000 0000 FC0C F000 0000 FCF0 0000"
	$"0000 F000 000F CFFF CF00 0000 F0F0 0000"
	$"0000 F000 000F 0C0C 0F00 0000 FCF0 0000"
	$"0000 F000 000F C0C0 CF00 0000 F0F0 0000"
	$"0000 F000 0000 FC0C F000 0000 FCF0 0000"
	$"0000 F000 0000 0FFF 0000 0000 F0F0 0000"
	$"0000 F000 0000 0F0F 0000 0000 FCF0 0000"
	$"0000 F000 0FFF FF0F FFFF 0000 F0F0 0000"
	$"0000 F000 F222 2FFF 2222 F000 FCF0 0000"
	$"0000 F00F 2222 2222 2222 2F00 F0F0 0000"
	$"0000 F00F FFFF FFFF FFFF FF00 FCF0 0000"
	$"0000 F00F C0C0 C0C0 C0C0 CF00 F0F0 0000"
	$"0000 F00F 0C0C 0C0C 0C0C 0F00 FCF0 0000"
	$"0000 F00F C0C0 C0C0 C0C0 CF00 F0F0 0000"
	$"0000 F000 FFFF FFFF FFFF F000 FCF0 0000"
	$"0000 F000 0000 0000 0000 0000 F0F0 0000"
	$"0000 F000 0333 3333 3300 0000 FCF0 0000"
	$"0000 F000 3333 3333 300F FFFF F0F0 0000"
	$"0000 F000 0000 0000 000F 000F 0CF0 0000"
	$"0000 F000 0000 0000 000F 00F0 C0F0 0000"
	$"0000 F000 0000 0000 000F 0F0C 0CF0 0000"
	$"0000 F000 0000 0000 000F F0C0 C0F0 0000"
	$"0000 FFFF FFFF FFFF FFFF 0C0C 0CF0 0000"
	$"0000 000F C0C0 C0C0 C0C0 C0C0 C0F0 0000"
	$"0000 000F FFFF FFFF FFFF FFFF FFF0"
};


resource 'ics4' (r_FinderBNDL, sysheap, purgeable) {
	$"FFFF FFFF FFFF FFF0 FCFF FFFF FFFF FFF0"
	$"F0F0 000F F000 0FF0 FCF0 00FF FF00 0FF0"
	$"F0F0 00FF 0F00 0FF0 FFF0 000F F000 0FFF"
	$"0FF0 0FFF FFF0 0FCF 0FF0 FFFF FFFF 0F0F"
	$"0FF0 FCCC CCCF 0FCF 0FF0 FFFF FFFF 0F0F"
	$"FFF0 0000 000F FFFF FCF0 0333 300F 0FF0"
	$"F0FF FFFF FFFF F0F0 FCFF FFFF FFFF FFF0"
	$"F0C0 C0C0 C0C0 C0F0 FFFF FFFF FFFF FFF0"
};


resource 'ics4' (r_StampPanelIcon, sysheap, purgeable) {
	$"0FFF FFFF FFFF FFF0 0F00 0000 0000 00F0"
	$"0F00 00FF 0000 00FF 0F00 0FFF F000 00FF"
	$"0F00 0FF0 F000 00FF 0F00 00FF 0000 00FF"
	$"0F00 FFFF FF00 00FF 0F0F FFFF FFF0 00FF"
	$"0F0F 0000 00F0 00FF 0F0F FFFF FFF0 00FF"
	$"0F00 0000 0000 00FF 0F00 3333 000F FFFF"
	$"0F00 0000 000F 00FF 0F00 0000 000F 0FFF"
	$"0FFF FFFF FFFF FFFF 00FF FFFF FFFF FFFF"
};
