/*
	FILENAME
		ChooserPACK.r

	DESCRIPTION
		Contains resources needed in order for this driver to work with
		the Chooser.

	COPYRIGHT
		Copyright  1995 Apple Computer, Inc.
		All rights reserved.
	
	Modification history
		10/04/95 - David Hayward -	Version 1.0.4 modified code so that
									the driver can be build under MPW,
									Metrowerks, and Symantec.  In general,
									all that was required to do this was 
									to add an inline-assembly jumptable
									and to store all globals off of the
									message manager instance context.
									Also made a few changes so that the
									driver can be rebuilt to support any
									resolution by changing the #defines
									kResolution and kPatStretch in
									"CommonDefines.h"

		06/14/95 - Dave Hersey -	Version 1.0.3 to fix a bug in
									CustomBufferingAndIO.c when creating
									high-res PICTs, and to make the size
									of buffers more flexible.

		05/26/95 - Dave Hersey -	Version 1.0.2 to add the new 'outp'
									desktop printer resource in NewApp.c.

		05/03/95 - Dave Hersey -	Version 1.0.1 to fix some minor bugs in
									CustomBufferingAndIO.c.

		01/14/95 - Dave Hersey -	Created from the shell of a hollowed-out
									ImageWriter driver.
*/


#include "Types.r"
#include "SysTypes.r"
#include "GXPrintingResTypes.r"
#include "GXPrintingResEquates.r"


//--------------------------------------------------------------------------------------------
// THINGS TO CONTROL THE DEFAULT CHOOSING MECHANISM
//--------------------------------------------------------------------------------------------

// The type of communication this device uses (this is the default, the
// actual value can be found in the desktop printer).

resource 'look' (-4096, sysheap, purgeable) {
	1,
	{
		"Not Connected",
		-4096,
		iconCells,
		"CustomWriter GX";
	};
};

resource 'comm' (-4096, sysheap, purgeable) {
	NotConnected {}
};


//--------------------------------------------------------------------------------------------
// STANDARD CHOOSER PACK STUFF
//--------------------------------------------------------------------------------------------

// title string (we'll put a control here, so we don't want a title)
resource 'STR ' (-4091, sysheap, purgeable)
{
	"";
};

// "left" button title
resource 'STR ' (-4093, sysheap, purgeable)
{
	"Create";
};

// rectangle list
resource 'nrct' (-4096, sysheap, purgeable) {
	{
	{112, 251, 132, 311};			// left button
	{0,0,0,0};						// right button
	{-20000, 180, -20000+20, 400};	// on button (location of "connect via"
									// popup is placed here, so I've moved
									// it offscreen).

	{0,0,0,0};						// off button
	{0,0,0,0};						// button label
	};
};

// Menu for the Chooser's connection type.
resource 'MENU' (-4096, sysheap, purgeable)
{
	-4096,
	textMenuProc,
	0xFFFFFFFF,	
	disabled,
	"",
	{}
};

// Pop-up control for the Chooser's connection type
resource 'CNTL' (-4096, sysheap, purgeable)
{
	{0, 0, 20, 213},							// zero based control location
	0,											// Title options 0 = Left justified
	visible,									// Should we display the control?
	95,											// Title Width
	-4096,										// 'MENU' to display
	popupMenuCDEFproc+popupFixedWidth,			// CDEF = CDEFID * 16 + varCode
	0, 											// refCon = ResType to append = None
	"Connect via:"								// Control title
};

resource 'DITL' (-4096, sysheap, purgeable) 
{
	{
		{3, 238, 23, 238 + 213}, 
		Control {enabled, -4096},
	};
};

