#==============================================================================================
#
#	Make FILE:		ImageWriterLQ.make
#
#	VERSION:		1.0
#
#	COPYRIGHT:		(c) 1992-1994 Apple Computer Inc.
#						All rights reserved.
#
#	PURPOSE:		This file contains the build commands for the
#					ImageWriter LQ driver.
#
#	4/26/93 - dmh - Made makefile totally self-supporting for b1 seed.
#	9/13/93 - dmh - Updated for the b2 seed.
#  12/18/93 - dmh - Updated for the b3 seed.
#	8/28/94 - dmh - Finalized for SDK.
#	6/14/96 - cn  - Updated to support MPW Pro #19.
#
#==============================================================================================

#======= Point these variables to your library directory =======

GXLibrariesSources			=	{MPW}GXLibraries:
GXCompatibilityInterfaces	=	{MPW}GX Compatibility Interfaces:

#========== Directories Containing Source and Object Files ==========

Objects					=	:Objects:
Sources					=	
Targets					=

#========== Compiler Options ==========

AsmOptions				=	-case obj
COptions				=	-d applec -b2 -i "{CIncludes}" -i "{GXLibrariesSources}" -i "{GXCompatibilityInterfaces}"
LinkOptions				=	-ra =resSysHeap,resPurgeable

#========== Printing Manager Dependent Header Files ==========

PrintManagerHeaderFiles	=	"{GXCompatibilityInterfaces}PrintingManager.h"		
							"{GXCompatibilityInterfaces}PrintingMessages.h"		
							"{GXCompatibilityInterfaces}PrintingExtensions.h"	
							"{CIncludes}Collections.h"							
							"{CIncludes}GXMessages.h"							
							"{GXCompatibilityInterfaces}PrintingResTypes.h"		
							"{GXCompatibilityInterfaces}PrintingErrors.h"

GraphicsHeaderFiles		=	"{GXCompatibilityInterfaces}graphics routines.h"	
							"{GXLibrariesSources}GraphicsLibraries.h"			
							"{GXCompatibilityInterfaces}math routines.h"			


#========== Files to Link into OldAPI Segment ==========

OldAPISegObjs	=	"{Objects}OldAPIMsgJumpTable.a.o"			
					"{Objects}OldAPIMessageIntf.c.o"			
					"{Libraries}"MacRuntime.o


#========== Files to Link into Universal Message Segment ==========

UnivSegObjs		=	"{Objects}UniversalMsgJumpTable.a.o"		
					"{Objects}UniversalMessageIntf.c.o"			
					"{Objects}DialogRoutines.c.o"				
					"{Objects}TextLibrary.c.o"					
					"{Objects}PictureLibrary.c.o"				
					"{Objects}FontLibrary.c.o"					
					"{Objects}ColorLibrary.c.o"					
					"{Objects}GraphicsLibrary.c.o"				
					"{Libraries}"MacRuntime.o					
					"{Libraries}"Interface.o					


#========== Files to Link into the Chooser PACK ==========

ChooserPackObjs =	"{Objects}ChooserSupport.a.o"				
					"{Objects}ChooserSupport.c.o"

#========== Files to Link into the Chooser LDEF ==========

ChooserLDEFObjs =	"{Objects}ChooserSupport.c.o"				


#========== Link and Rez Build Statements ==========

"ImageWriterLQ"		{OldAPISegObjs} 							
					{UnivSegObjs}								
					{ChooserPackObjs}							
					{ChooserLDEFObjs}							
					"{Sources}ImageWriterLQ.make"				
					"{Sources}LQResources.r"					
					"{Sources}OldAPIResources.r"				
					"{Sources}UniversalMessageResources.r"
		Link {OldAPISegObjs}									
			  {LinkOptions}										
			  -rt pdvr=1										
			  -sg "ImageWriterLQ"								
			  -m SD_OldAPIMsgJumpTable							
			  -o "{Objects}IWLQ_OldAPISeg"
		Link {UnivSegObjs}										
			  {LinkOptions}										
			  -rt pdvr=0										
			  -sg "ImageWriterLQ"								
			  -m SD_UniversalMsgJumpTable						
			  -o "{Objects}IWLQ_UnivSeg"
		Link	{ChooserPackObjs}								
				-rt PACK=-4096									
				-sg PrintingPACK								
				-m EntryPoint									
				-o "{Objects}IWLQ_PACK"
		Link	{ChooserLDEFObjs}								
				-w												
				-rt LDEF=-4096									
				-sg LDEF										
				-m LDEF											
				-o "{Objects}IWLQ_LDEF"
		Rez	-rd -i "{RIncludes}" -c 'scLQ' -t 'pdvr' -ov -s {Objects} 
				-o "{Targets}ImageWriterLQ" "{Sources}LQResources.r" "{Sources}OldAPIResources.r" 
				"{Sources}UniversalMessageResources.r" "{Sources}ChooserSupport.r" -append


#========== Assemble Build Statements - OldAPIMsgJumpTable.a ==========

"{Objects}OldAPIMsgJumpTable.a.o"		 	"{Sources}OldAPIMsgJumpTable.a"		
											"{Sources}ImageWriterLQ.make"
	Asm {AsmOptions} {MakeJumpTable} "{Sources}OldAPIMsgJumpTable.a" -o "{Objects}OldAPIMsgJumpTable.a.o"
	

#========== Assemble Build Statements - UniversalMsgJumpTable.a ==========

"{Objects}UniversalMsgJumpTable.a.o"	 	"{Sources}UniversalMsgJumpTable.a"	
											"{Sources}ImageWriterLQ.make"
	Asm {AsmOptions} {MakeJumpTable} "{Sources}UniversalMsgJumpTable.a" -o "{Objects}UniversalMsgJumpTable.a.o"
	

#========== Assemble Build Statements - ChooserSupport.a ==========

"{Objects}ChooserSupport.a.o"	 	"{Sources}ChooserSupport.a"		
									"{Sources}ImageWriterLQ.make"
	Asm {AsmOptions} {MakeJumpTable} {Sources}ChooserSupport.a -o {Objects}ChooserSupport.a.o


#========== Compile Build Statements - OldAPIMessageIntf.c ==========

"{Objects}OldAPIMessageIntf.c.o"		"{Sources}OldAPIMessageIntf.c"	
										{PrintManagerHeaderFiles}		
										{GraphicsHeaderFiles}			
										"{Sources}ImageWriterLQ.make"	
										"{Sources}LQResources.h" 			
										"{Sources}OldAPIMessageIntf.h"
	SC "{Sources}OldAPIMessageIntf.c" -o "{Objects}OldAPIMessageIntf.c.o"  {COptions}


#========== Compile Build Statements - UniversalMessageIntf.c ==========

"{Objects}TextLibrary.c.o"			 "{GXLibrariesSources}TextLibrary.c"
	SC {COptions} -o {Objects} "{GXLibrariesSources}TextLibrary.c"

"{Objects}PictureLibrary.c.o"		 "{GXLibrariesSources}PictureLibrary.c"
	SC {COptions} -o {Objects} "{GXLibrariesSources}PictureLibrary.c"

"{Objects}FontLibrary.c.o"			 "{GXLibrariesSources}FontLibrary.c"
	SC {COptions} -o {Objects} "{GXLibrariesSources}FontLibrary.c"

"{Objects}ColorLibrary.c.o"		 "{GXLibrariesSources}ColorLibrary.c"
	SC {COptions} -o {Objects} "{GXLibrariesSources}ColorLibrary.c"

"{Objects}GraphicsLibrary.c.o"		 "{GXLibrariesSources}GraphicsLibrary.c"
	SC {COptions} -o {Objects} "{GXLibrariesSources}GraphicsLibrary.c"


"{Objects}UniversalMessageIntf.c.o"		"{Sources}UniversalMessageIntf.c"		
										{PrintManagerHeaderFiles}				
										{GraphicsHeaderFiles}					
										"{Sources}ImageWriterLQ.make"			
										"{Sources}LQResources.h" 					
										"{Sources}UniversalMessageIntf.h"
	SC "{Sources}UniversalMessageIntf.c" -o "{Objects}UniversalMessageIntf.c.o"  {COptions}


#========== Compile Build Statements - ChooserSupport.c ==========

"{Objects}ChooserSupport.c.o"		"{Sources}ChooserSupport.c"			
									{PrintManagerHeaderFiles}			
									{GraphicsHeaderFiles}				
									"{Sources}ImageWriterLQ.make"		
									"{Sources}ChooserSupport.a" 		
									"{Sources}ChooserSupport.r"
	SC "{Sources}ChooserSupport.c" -o "{Objects}ChooserSupport.c.o"  {COptions}


#========== Compile Build Statements - DialogRoutines.c ==========

"{Objects}DialogRoutines.c.o"		"{Sources}DialogRoutines.c"			
									"{Sources}DialogRoutines.h"			
									{PrintManagerHeaderFiles}			
									{GraphicsHeaderFiles}				
									"{Sources}ImageWriterLQ.make"		
									"{Sources}LQResources.h" 			
									"{Sources}UniversalMessageIntf.h"
	SC "{Sources}DialogRoutines.c" -o "{Objects}DialogRoutines.c.o"  {COptions}


