/* ------------------------------------------------------------------------------
FILENAME
	OldAPIResources.r

DESCRIPTION
	This module contains the LaserWriter SC resource constants and types that
	are needed to support the old (i.e. QuickDraw) application printing interface.
	
	Note: resources specific to the old API (e.g. print and style dialog resources)
	must retain the original resource ID's (e.g. -8192).  Don't set these resource
	ID's to be based upon printingDriverBaseID.  Also note that all resources
	should be designated to load into the system heap.
		
COPYRIGHT
	 Copyright Apple Computer, Inc. 1988-1996
	 All rights reserved. 

MODIFICATION HISTORY
	 6/14/96 - cn  - Updated to support Universal Interfaces 2.1.
	
-------------------------------------------------------------------------------- */

// System 7.0 Compatible
#define SystemSevenOrLater		1

// Include System Resource Definitions
#include "Types.r"
#include "SysTypes.r"
#include "BalloonTypes.r"

// Include the LaserWriter SC driver constants that are used in the resources 
#include "LaserSCResources.h"

// Include the public QuickDraw GX printing files 
#include "GXPrintingResTypes.r"


/*********************************************************************************
 *        							TYPES 				 						 					*
 *********************************************************************************/

type 'PREC' (0) 			// LaserWriter SC - Old Style Print Record Definition that should be compatible with Syste, 7.0 version of LW SC driver
{
	integer = 3;										//iPrVersion - 3 = last version of LW SC driver before QuickDraw GX version
	
	
															//PrInfo 
	integer;													//	iDev 
	integer;													//	iVRes 
	integer;													//	iHRes 
	rect;														//	rPage 
	
	
	rect;													//rPaper 
	
	
															//PrStl 
	byte;														//	wDev refNum	
	boolean NoIWf7, IWf7;								//	wDev f7 (NOT USED) 
	boolean NoIWDftBits, IWDftBits;					//	wDev f6, fDraftBits (NOT USED) 
	boolean NoIWResSet, IWResSet;						//	wDev f5, fResSet (NOT USED) 
	boolean NoIWScroll, IWScroll;						//	wDev f4, fScroll (NOT USED) 
	boolean NoIW2xZoom, IW2xZoom;						//	wDev f3, f2xZoom (NOT USED) 
	boolean NoIWSqPix, IWSqPix;						//	wDev f2, fSqPix (NOT USED) 
	boolean Landscape, Portrait;						//	wDev f1, fPortrait 
	boolean IWLowRes, IWHighRes;						//	wDev f0, fHiRes (NOT USED) 
	integer;													//	iPageV 
	integer;													//	iPageH 
	byte;														//	bPort 
	byte HandFeed, AutoFeed, Other1, Other2;		//	feed: the old SC driver defined AutoFeed as 1 and Manual as 0.	
	
	
															//PrInfoPT 
	integer = 0xFD00;										//	iDev: Font mgr/QuickDraw device code
	integer;													//	iVRes 
	integer;													//	iHRes 
	rect;														//	rPage 
	
	
															//PrXInfo 
	integer;													// iCopies 
	boolean Nof15, Yesf15;								//	wFlags f15, f?? 
	boolean Nof14, Yesf14;								//	wFlags f14, f?? 
	boolean Nof13, Yesf13;								//	wFlags f13, f?? 
	boolean Nof12, Yesf12;								//	wFlags f12, f?? 
	boolean Nof11, Yesf11;								//	wFlags f11, f?? 
	boolean Nof10, Yesf10;								//	wFlags f10, f?? 
	boolean NoGrayScl, YesGrayScl;					//	wFlags f9,  fGrayScl {B10}	
	boolean YesAbortCk, NoAbortCk;					//	wFlags f8,  fNoAbortCheck {B10}	
	boolean NoScale25, Scale25;						//	wFlags f7,  fScale25	
	boolean NoDftBits, DftBits;						//	wFlags f6,  fDraftBits 
	boolean NoResSet, ResSet;							//	wFlags f5,  fResSet 
	boolean NoBits4x, Bits4x;							//	wFlags f4,  f4xBits 
	boolean NoScale50, Scale50;						//	wFlags f3,  fScale50	
	boolean NoScale75, Scale75;						//	wFlags f2,  fScale75	
	boolean XLandscape, XPortrait;					//	wFlags f1,  fPortrait (NOT USED)
	boolean NoTxSmooth, TxSmooth;						//	wFlags f0,  fTxSmooth 
	integer;													//	iBandh 
	integer;													//	iDevBytes 
	integer;													//	iBands 
	byte dbl=-2, norm=0;									//	bPatScale 
	byte;														//	bULThick	
	byte;														//	bULOffset 
	byte;														//	bULShadow 
	byte scanTB, scanBT, scanLR, scanRL;			//	scan 
	fill byte;												//	bXInfoX 
	
	
															//PrJob 
	integer;													//	iFstPage	
	integer;													//	iLstPage	
	integer;													//	iFakeCopies	
	byte Draft, Spool, User1, User2;					//	bJDocLoop 
	byte;														//	fFromUsr	
	longint;													//	pIdleProc 
	longint;													//	pFileName 
	integer;													//	iFileVol	
	byte;														//	bFileVers 
	byte;														//	bJobFlags 
															// Make 120 byte total 
	fill word [5];											// not used
	rect;														// contains a copy of rPaper
	fill word [10];										// not used	
};


/*********************************************************************************
 *        							RESOURCES 			 						 					*
 *********************************************************************************/

/*************************** Old API Message Override Resource **************************/
// This overrideType resource tells the Printing Manager which old API messages we want to override, 
// as well as some new backward compatibility messages. 

resource gxOverrideType (gxDriverCompatibilityOverrideID, sysHeap)
{
	{
		gxPrValidate, 					kOldAPISegmentID, kFirstMsgJumpTableOffset,
		gxConvertPrintRecordTo, 	kOldAPISegmentID, kFirstMsgJumpTableOffset + 4,
		gxConvertPrintRecordFrom, 	kOldAPISegmentID, kFirstMsgJumpTableOffset + 8,
		gxPrOpenDoc, 					kOldAPISegmentID, kFirstMsgJumpTableOffset + 12,
	};
};


/*************************** Old Application Compatibility Resource **************************/
// This custType resource is used by the Printing Manager.  It defines some basic options for 
// use with old applications.  Note: every driver should contain one of these resources. 

resource gxCustType (gxCustID, purgeable, sysHeap)
{
	kHorizHighRes,						// horizontal device resolution (dpi) 
	kVertHighRes, 						// vertical device resolution (dpi) 
	laserWriterSC,						// type of "upDriver" to use 
	{4, 4},								// pattern stretching factor. Set to 4 (nearest thing to 300 dpi/72 dpi) 
	gxReplaceLineWidthTranslation + gxOptimizedTranslation + gxRasterTargetTranslation	// SC Style LineWidth comments 
};


/************************** PREC Resources **************************/
// This PREC definition represents the default print record definition 
// for the old LaserWriter SC driver. This resource is accessed by the 
// Universal Dialog Handler. 
#define	kVertRPaperDefault		1320
#define	kHorizRPaperDefault		1020

resource 'PREC' (0, sysHeap)			// PREC 0 - Default print record definition for the old LaserWriter SC driver 
{
	// PrInfo 
	0,
	72,					// app resolution
	72,
	{kRPageDefault},
		
	// rPaper 
	{kRPaperDefault},
	
	// PrStl 
	kPrinterID,
	NoIWf7,
	NoIWDftBits,
	NoIWResSet,
	NoIWScroll,
	NoIW2xZoom,
	NoIWSqPix,
	Portrait,
	IWHighRes,
	kVertRPaperDefault,
	kHorizRPaperDefault,
	0,
	AutoFeed,
	
	// PrInfoPT 	
	kVertHighExactRes,
	kHorizHighExactRes,
	{kRPageHighExactRes},
	
	// PrXInfo 
	0,
	Nof15,
	Nof14,
	Nof13,
	Nof12,
	Nof11,
	Nof10,
	YesGrayScl,
	YesAbortCk,
	NoScale25,
	NoDftBits,
	NoResSet,
	NoBits4x,
	NoScale50,
	NoScale75,
	XPortrait,
	NoTxSmooth,
	0,
	0,
	0,
	kPatScale,
	kULThick,
	kULOffset,
	kULShadow,
	kScanDirection,
	
	// PrJob 
	1,
	9999,
	1,
	Draft,
	1,
	0,
	0,
	0,
	0,
	0,

	// PrintX
	{kRPaperDefault}
};


// version string for old dialogs
resource 'STR ' (-8190, sysHeap ) { "1.1" };

/************************** PrStlDialog Resources **************************/
// These dialog related resources define the old LaserWriter SC's Style dialog. 
// These resources are manipulated by the Universal Dialog Handler 

resource 'DLOG' (gxStlDialogResID, sysHeap)				// Style Dialog DLOG 
{
	{30, 20, 208, 492},
	dBoxProc,
	invisible,
	noGoAway,
	0x1,
	gxStlDialogResID,
	"Stl",
	noAutoCenter
};

resource 'DITL' (gxStlDialogResID, sysHeap)				// Style Dialog DITL 
{
	{	// array DITLarray: 21 elements 

		{8, 404, 27, 464}, Button { enabled, "OK" },
		{35, 404, 54, 464}, Button { enabled, "Cancel" },
		{4, 4, 20, 265}, StaticText { disabled, "!0 Page Setup" },		//	!0 substitutes the name of the driver
		{20, 5, 24, 393}, UserItem { disabled },

		{88, 4, 104, 88}, StaticText { disabled, "Orientation:" },
		{106, 4, 138, 36}, UserItem { enabled },			// Orientation 
		{106, 41, 138, 73}, UserItem { enabled },			// Orientation 

		{32, 4, 48, 50}, StaticText { disabled, "Paper:" },
		{32, 64, 48, 164}, RadioButton { enabled, "US Letter" },
		{48, 64, 64, 164}, RadioButton { enabled, "US Legal" },
		{32, 192, 48, 282}, RadioButton { enabled, "A4 Letter" },
		{48, 192, 64, 282}, RadioButton { enabled, "B5 Letter" },
		{64, 64, 80, 191}, RadioButton { enabled, "N 10 Envelope" },

		{88, 100, 104, 174}, StaticText { disabled, "Reduction:" },
		{88, 250, 106, 458}, CheckBox { enabled, "Exact Bit Images (Shrink 4%)" },
		
		{4, 341, 19, 365}, UserItem { enabled },			// area for version number 
		{0, 395, 27, 465}, UserItem { disabled },			// user item for OK button 

		{88, 174, 104, 234}, RadioButton { enabled, "100%" },
		{103, 174, 119, 234}, RadioButton { enabled, "75%" },
		{118, 174, 134, 234}, RadioButton { enabled, "50%" },
		{133, 174, 149, 234}, RadioButton { enabled, "25%" }
	}
};

resource 'dctl' (gxStlDialogResID, sysHeap)				// Universal Dialog Handler dctl for Style Dialog 
{
	21,
	{
		Button {2, cancel},
		Frill {3, printerName},
		Frill {4, line},
		Orientation {6, 7, 0, 0},
		PaperSizes {0, 0, { 9, 10, 11, 12, 13 }},
		Toggle {15, bPreciseBitmap},
		Frill {16, version},
		Frill {17, default},
		Cluster {user0, {18, 19, 20, 21 }},
	}
};



// This resource is needed for proper use of color in Style dialog
resource 'dctb' (gxStlDialogResID, sysheap, purgeable)
{
	{	/* array ColorSpec: 0 elements */
	}
};


/************************** PrJobDialog Resources **************************/
// These dialog related resources define the old LaserWriter SC's Print dialog. 
// These resources are manipulated by the Universal Dialog Handler 

resource 'DLOG' (gxJobDialogResID, sysHeap) 			// Job Dialog DLOG 
{
	{28, 26, 156, 500},
	dBoxProc,
	invisible,
	noGoAway,
	0x1,
	gxJobDialogResID,
	"Job",
	noAutoCenter
};

resource 'DITL' (gxJobDialogResID, sysHeap) 			// Job Dialog DITL 
{
	{	// array DITLarray: 20 elements 
		{8, 404, 27, 464}, Button { enabled, "Print" },
		{35, 404, 54, 464}, Button { enabled, "Cancel" },
		{4, 4, 20, 265}, StaticText { disabled, "!0 Print " },		//	!0 substitutes the name of the driver
		{20, 5, 24, 393}, UserItem { disabled },
		{94, 400, 114, 460}, UserItem { disabled },

		{38, 112, 54, 157}, StaticText { disabled, "Pages:" },
		{38, 157, 54, 197}, RadioButton { enabled, "All" },
		{38, 200, 54, 260}, RadioButton { enabled, "From:" },
		{38, 264, 54, 296}, EditText { enabled, "" },
		{38, 304, 54, 326}, StaticText { disabled, "To:" },

		{38, 332, 54, 364}, EditText { enabled, "" },
		{38, 4, 54, 54}, StaticText { disabled, "Copies:" },
		{38, 56, 54, 88}, EditText { disabled, "1" },
		{68, 4, 84, 98}, StaticText { disabled, "Paper Source:" },
		{68, 100, 84, 222}, RadioButton { enabled, "Paper Cassette" },

		{68, 230, 84, 333}, RadioButton { enabled, "Manual Feed" },
		{4, 341, 19, 365}, UserItem { enabled },
		{0, 395, 27, 465}, UserItem { disabled },
	}
};

resource 'dctl' (gxJobDialogResID, sysHeap)				// Universal Dialog Handler dctl for Job Dialog 
{
	19,
	{
		Button {2,	cancel },
		Frill {3, printerName },
		Frill {4, line },
		Copies {13 },
		PageRange {7, 8, 9, 11 },
		Cluster {feed, { 15, 16 } },
		Frill {17, version },
		Frill {18, default },
		DialogBtn {19, 3, 3},
	}
};


// This resource is needed for proper use of color in Job dialog
resource 'dctb' (gxJobDialogResID, sysheap, purgeable)
{
	{	/* array ColorSpec: 0 elements */
	}
};


/*************************** Old API Paper Type Definitions **************************/
// These paper type definitions represent the settings of the old LaserWriter SC's paper 
// sizes. 

resource 'ptyp' (kOldPaperTypesID + 1, sysHeap)			// US Letter 
{
	"US Letter",
	
	// page rectangle 
	0x00000000,				// 0.0 
	0x00000000,				// 0.0 
	0x02400000,				// 8.0 
	0x02FB0000,				// 10.5972 

	// paper rectangle 
	0xFFEE0000,				// -0.25 
	0xFFF10000,				// -0.25 
	0x02520000,				// 8.24 
	0x03090000,				// 10.75 
	
	usLetterBase,
	kDrvrCreatorType,

	inch,
	oldStylePaperType,
	isDefaultPaperType,
	{}
};

resource 'ptyp' (kOldPaperTypesID + 2, sysHeap)			// US Legal 
{
	"US Legal",
	
	// page rectangle 
	0x00000000,					/* 6.75 x 12.0 */
	0x00000000,				
	0x01E60000,					
	0x03600000,				

	// paper rectangle 
	0xFFF1D70A,				// -0.196667 
	0xFFF851F0,				// -0.106666 
	0x0255D70C,				// 8.30333 
	0x03E851F0,				// 13.8933 

	usLegalBase,
	kDrvrCreatorType,

	inch,	
	oldStylePaperType,
	notDefaultPaperType,
	{}
};

resource 'ptyp' (kOldPaperTypesID + 3, sysHeap)			// A4 Letter 
{
	"A4 Letter",
	
	// page rectangle 
	0x00000000,				// 8.00 x 11.25 
	0x00000000,
	0x02400000,
	0x032A0000,

	// paper rectangle 
	0xFFF70000,				//	8.25 x 11.66
	0xFFF10000,
	0x02490000,
	0x0338C298,
	
	a4LetterBase,
	kDrvrCreatorType,

	inch,	
	oldStylePaperType,
	notDefaultPaperType,
	{}
};

resource 'ptyp' (kOldPaperTypesID + 4, sysHeap)			// B5 Letter 
{
	"B5 Letter",
	
	// page rectangle 
	0x00000000,				// 6.6667 x 9.4167 
	0x00000000,				
	0x01DFC290,				
	0X02C251EC,				

	// paper rectangle 
	-0x14A3D7,				// 6.9306 x 9.8333
	-0x73338,				
	0x01F46667,				
	0x02C98524,				

	b5LetterBase,
	kDrvrCreatorType,

	inch,	
	oldStylePaperType,
	notDefaultPaperType,
	{}
};

resource 'ptyp' (kOldPaperTypesID + 5, sysHeap)			// N 10 Envelope 
{
	"N 10 Envelope",
	
	// page rectangle 
	0x00000000,					// 9.1 x 3.73 
	0x00000000,					
	0x010C8F5C,					
	0x028F3333,					
	
	// paper rectangle 
	0xFFF1BE77,					// 9.5 x 4.125 
	0xFFF1999A,					
	0x011AD0E5,					
	0x029D9999,					

	unknownBase,
	kDrvrCreatorType,

	inch,
	oldStylePaperType,
	notDefaultPaperType,
	{}
};


/*************************** Help Manager Resource Definitions **************************/
// These resources define the help text that will be displayed by the System 7 Help Manager
// if help is enabled and on eof the print dialogs is visible.


// The 'hwin' resource is used by the Help Manager and it links 'hdlg'
// resources to the dialogs to which they apply.  In this case, we have
// two 'hwin' list entries that reference the two old app. print dialogs.

resource 'hwin' (kHwinRsrcID, purgeable, sysheap)
{
	HelpMgrVersion,
	hmDefaultOptions,
	{
		gxStlDialogResID, 'hdlg', 3, "Stl",		// Reference to PrStlDialog's 'hdlg' resource
		gxJobDialogResID, 'hdlg', 3, "Job"		// Reference to PrJobDialog's 'hdlg' resource
	}
};


// The 'hfdr' resource tells the Finder that we have help information it should
// display when the user moves the mouse over the LaserWriter IISC icon when help is enabled.

resource 'hfdr' (kHfdrRsrcID, purgeable, sysheap)
{
	HelpMgrVersion,
	hmDefaultOptions,
	0,					// Default balloon definition function
	0,					// Default variation code
	{
		HMSTRResItem
		{
			kFinderHelpSTRID	// Resource ID of help string ('STR ') to display
		}
	}
};


// This string resource contains the help text that will be displayed in the Finder if you
// move the mouse over the LaserWriter IISC icon when help is enabled.

resource 'STR ' (kFinderHelpSTRID, purgeable, sysheap)
{
	"LaserWriter IISC\n\n"
	"To enable your Macintosh to print documents on a LaserWriter IISC connected to the SCSI port, place this file in your Extensions folder.";
};


// This 'hdlg' resource tells the system what help strings to display when the user moves
// the mouse over the LaserWriter IISC's Style dialog with help enabled.

resource 'hdlg' (gxStlDialogResID, purgeable, sysheap)
{
	HelpMgrVersion,
	0,										// Start help with the first item in the corresponding 'DITL'
	hmDefaultOptions,
	0,										// Default balloon definition function
	0,										// Ballon variation code - hang below and to the right
	HMStringResItem					//	This list references help strings to be used for any missing items
	{
		{0, 0},
		{0, 0, 0, 0},
		gxStlDialogResID, 1,
		gxStlDialogResID, 2,
		gxStlDialogResID, 3,
		gxStlDialogResID, 4
	},
	{
		/* [1] */
		HMStringResItem 
		{									// OK button
			{0, 0},						//	default tip: middle right edge of item rect
			{0, 0, 0, 0},				//	default alternate rectangle: use item rect
			gxStlDialogResID, 5,
			gxStlDialogResID, 6,
			gxStlDialogResID, 7,
			gxStlDialogResID, 8
		},
		/* [2] */
		HMStringResItem 
		{									// Cancel button
			{0, 0},	
			{0, 0, 0, 0},
			gxStlDialogResID, 9,
			gxStlDialogResID, 10,
			gxStlDialogResID, 11,
			gxStlDialogResID, 12
		},
		/* [3] */
		HMSkipItem 
		{									// Title of the dialog - LaserWriterIISC Page Setup
		},
		/* [4] */
		HMSkipItem 
		{									//	Horizontal line
		},
		/* [5] */
		HMSkipItem 
		{									// Orientation string
		},
		/* [6] */
		HMStringResItem
		{									// Portrait orientation
			{0, 0},
			{0, 0, 0, 0},
			gxStlDialogResID, 33,
			gxStlDialogResID, 34,
			gxStlDialogResID, 35,
			gxStlDialogResID, 36
		},
		/* [7] */	
		HMStringResItem 
		{									// Landscape orientation
			{0, 0},
			{0, 0, 0, 0},
			gxStlDialogResID, 37,
			gxStlDialogResID, 38,
			gxStlDialogResID, 39,
			gxStlDialogResID, 40
		},
		/* [8] */
		HMSkipItem 
		{									// Paper string
		},
		/* [9] */
		HMStringResItem 
		{									//	US Letter button
			{0, 0},
			{0, 0, 0, 0},
			gxStlDialogResID, 13,
			gxStlDialogResID, 14,
			gxStlDialogResID, 15,
			gxStlDialogResID, 16
		},
		/* [10] */
		HMStringResItem 
		{									//	US Legal button
			{0, 0},
			{0, 0, 0, 0},
			gxStlDialogResID, 21,
			gxStlDialogResID, 22,
			gxStlDialogResID, 23,
			gxStlDialogResID, 24
		},
		/* [11] */
		HMStringResItem 
		{									//	A4 Letter button
			{0, 0},
			{0, 0, 0, 0},
			gxStlDialogResID, 17,
			gxStlDialogResID, 18,
			gxStlDialogResID, 19,
			gxStlDialogResID, 20
		},
		/* [12] */
		HMStringResItem 
		{									//	B5 Letter button
			{0, 0},
			{0, 0, 0, 0},
			gxStlDialogResID, 25,
			gxStlDialogResID, 26,
			gxStlDialogResID, 27,
			gxStlDialogResID, 28
		},
		/* [13] */
		HMStringResItem 
		{									// No. 10 Envelope button
			{0, 0},
			{0, 0, 0, 0},
			gxStlDialogResID, 29,
			gxStlDialogResID, 30,
			gxStlDialogResID, 31,
			gxStlDialogResID, 32
		},
		/* [14] */
		HMStringResItem 
		{									//	Reduction string
			{0, 0},
			{0, 0, 0, 0},
			gxStlDialogResID, 33,
			gxStlDialogResID, 34,
			gxStlDialogResID, 35,
			gxStlDialogResID, 36
		},
		/* [15] */
		HMStringResItem 
		{									// Exact bit images check box
			{0, 0},
			{0, 0, 0, 0},
			gxStlDialogResID, 53,
			gxStlDialogResID, 54,
			gxStlDialogResID, 55,
			gxStlDialogResID, 56
		},
		/* [16] */
		HMSkipItem {					//	Version number string

		},
		/* [17] */
		HMSkipItem 
		{									//	User item for the OK button
		},
		/* [18] */
		HMStringResItem 
		{									//	100% reduction button
			{0, 0},
			{0, 0, 0, 0},
			gxStlDialogResID, 41,
			gxStlDialogResID, 42,
			gxStlDialogResID, 43,
			gxStlDialogResID, 44
		},
		/* [19] */
		HMStringResItem 
		{									//	75% reduction button
			{0, 0},
			{0, 0, 0, 0},
			gxStlDialogResID, 45,
			gxStlDialogResID, 46,
			gxStlDialogResID, 47,
			gxStlDialogResID, 48
		},
		/* [20] */
		HMStringResItem 
		{									// 50% reduction button
			{0, 0},
			{0, 0, 0, 0},
			gxStlDialogResID, 49,
			gxStlDialogResID, 50,
			gxStlDialogResID, 51,
			gxStlDialogResID, 52
		},
		/* [21] */
		HMStringResItem
		{									// 25% reduction button
			{0, 0},
			{0, 0, 0, 0},
			gxStlDialogResID, 57,
			gxStlDialogResID, 58,
			gxStlDialogResID, 59,
			gxStlDialogResID, 60
		}
	}
};

// This 'hdlg' resource tells the system what help strings to display when the user moves
// the mouse over the LaserWriter IISC's Print dialog with help enabled.

resource 'hdlg' (gxJobDialogResID, purgeable, sysheap)
{
	HelpMgrVersion,
	0,										// Start help with the first item in the corresponding 'DITL'
	hmDefaultOptions,
	0,										// Default balloon definition function
	0,										// Ballon variation code - hang below and to the right
	HMStringResItem					//	This list references help strings to be used for any missing items
	{
		{0, 0},
		{0, 0, 0, 0},
		gxJobDialogResID, 1,
		gxJobDialogResID, 2,
		gxJobDialogResID, 3,
		gxJobDialogResID, 4
	},
	{
		/* [1] */
		HMStringResItem
		{									// Print button
			{0, 0},
			{0, 0, 0, 0},
			gxJobDialogResID, 5,
			gxJobDialogResID, 6,
			gxJobDialogResID, 7,
			gxJobDialogResID, 8
		},
		/* [2] */
		HMStringResItem
		{									// Cancel button
			{0, 0},
			{0, 0, 0, 0},
			gxJobDialogResID, 9,
			gxJobDialogResID, 10,
			gxJobDialogResID, 11,
			gxJobDialogResID, 12
		},
		/* [3] */
		HMSkipItem
		{									// Title of the print dialog
		},
		/* [4] */
		HMSkipItem
		{									// Horizontal line
		},
		/* [5] */
		HMSkipItem
		{									// A dummy user item
		},
		/* [6] */
		HMSkipItem
		{									// Pages string
		},
		/* [7] */
		HMStringResItem				
		{									// All button
			{0, 0},
			{0, 0, 0, 0},
			gxJobDialogResID, 17,
			gxJobDialogResID, 18,
			gxJobDialogResID, 19,
			gxJobDialogResID, 20
		},
		/* [8] */
		HMStringResItem
		{									// From button
			{0, 0},
			{0, 0, 0, 0},
			gxJobDialogResID, 21,
			gxJobDialogResID, 22,
			gxJobDialogResID, 23,
			gxJobDialogResID, 24
		},
		/* [9] */
		HMStringResItem 
		{									// Edittext field for the starting page number
			{0, 0},
			{0, 0, 0, 0},
			gxJobDialogResID, 25,
			gxJobDialogResID, 26,
			gxJobDialogResID, 27,
			gxJobDialogResID, 28
		},
		/* [10] */
		HMSkipItem 
		{									// To string
		},
		/* [11] */
		HMStringResItem
		{									// Edittext field for the ending page number
			{0, 0},
			{0, 0, 0, 0},
			gxJobDialogResID, 29,
			gxJobDialogResID, 30,
			gxJobDialogResID, 31,
			gxJobDialogResID, 32
		},
		/* [12] */
		HMSkipItem 
		{									// Copies string
		},
		/* [13] */
		HMStringResItem 
		{									//	Edittext for the number of copies
			{0, 0},
			{0, 0, 0, 0},
			gxJobDialogResID, 13,
			gxJobDialogResID, 14,
			gxJobDialogResID, 15,
			gxJobDialogResID, 16
		},
		/* [14] */
		HMSkipItem 
		{									//	Paper Source string
		},
		/* [15] */
		HMStringResItem 
		{									// Paper cassette button
			{0, 0},
			{0, 0, 0, 0},
			gxJobDialogResID, 33,
			gxJobDialogResID, 34,
			gxJobDialogResID, 35,
			gxJobDialogResID, 36
		},
		/* [16] */
		HMStringResItem 
		{									// Manual Feed button
			{0, 0},
			{0, 0, 0, 0},
			gxJobDialogResID, 37,
			gxJobDialogResID, 38,
			gxJobDialogResID, 39,
			gxJobDialogResID, 40
		},
		/* [17] */
		HMSkipItem 
		{									// Version string
		},
		/* [18] */
		HMSkipItem 
		{									// User item surrounding Print button
		}
	}
};

// This 'STR#' resource contains the help strings that are referenced in the 'hdlg' resource
// that corresponds to the PrStlDialog.

resource 'STR#' (gxStlDialogResID, purgeable, sysheap)
{
	{
		/* [1] */	"Missing enabled item in hdlg -8192",
		/* [2] */	"Missing disabled item in hdlg -8192",
		/* [3] */	"Missing checked item in hdlg -8192",
		/* [4] */	"Missing other item in hdlg -8192",
		/* [5] */	"To confirm the settings in this box and close the box, click this button (or press the Return or Enter key).",
		/* [6] */	"",
		/* [7] */	"",
		/* [8] */	"",
		/* [9] */	"To cancel any changes you have made to the settings in this box and close the box, click this button.",
		/* [10] */	"",
		/* [11] */	"",
		/* [12] */	"",
		/* [13] */	"To print your document with standard U.S. letter paper (8 1/2 by 11 inches), click this button.",
		/* [14] */	"",
		/* [15] */	"When this button is selected, your document is set up for standard U.S. letter "
						"paper (8 1/2 by 11 inches).",
		/* [16] */	"",
		/* [17] */	"To print your document with A4 paper (a standard European letter size, 8 1/2 by "
						"11 2/3 inches), click this button.",
		/* [18] */	"",
		/* [19] */	"When this button is selected, your document is set up for A4 paper (a standard "
						"European letter size, 8 1/2 by 11 2/3 inches).",
		/* [20] */	"",
		/* [21] */	"To print your document with U.S. legal paper (8 1/2 by 14 inches), click this button.",
		/* [22] */	"",
		/* [23] */	"When this button is selected, your document will be set up for U.S. legal paper (8 1/2 by 14 inches).",
		/* [24] */	"",
		/* [25] */	"To print your document with B5 paper (a standard European letter size, approximately 6 by 10 inches), click this button.",
		/* [26] */	"",
		/* [27] */	"When this button is selected, your document is set up for B5 paper (a standard "
						"European letter size, approximately 6 by 10 inches).",
		/* [28] */	"",
		/* [29] */	"To print your document on number 10 (U.S. business-size) envelopes, click this button.",
		/* [30] */	"",
		/* [31] */	"When this button is selected, your document is set up for number 10 (business-size) envelopes.",
		/* [32] */	"",
		/* [33] */	"To set up your document for portrait (tall) printing, click this icon.",
		/* [34] */	"",
		/* [35] */	"When this icon is selected, your document is set up for portrait (tall) printing.",
		/* [36] */	"",
		/* [37] */	"To set up your document for landscape (wide) printing, click this icon.",
		/* [38] */	"",
		/* [39] */	"When this icon is selected, your document is set up for landscape (wide) printing.",
		/* [40] */	"",
		/* [41] */	"To print your document full size (with no reduction), click this button.",
		/* [42] */	"",
		/* [43] */	"When this button is selected, your document is printed at full size (with no reduction).",
		/* [44] */	"",
		/* [45] */	"To print your document at three-quarters its actual size, click this button.",
		/* [46] */	"To print your document at three-quarters its actual size, click this button.  Not "
						"available because the application program you are using always prints images at actual size.",
		/* [47] */	"When this button is selected, your document is printed at three-quarters its actual size.",
		/* [48] */	"",
		/* [49] */	"To print your document at one-half its actual size, click this button.",
		/* [50] */	"To print your document at one-half its actual size, click this button.  Not available "
						"because the application program you are using always prints images at actual size.",
		/* [51] */	"When this button is selected, your document is printed at one-half its actual size.",
		/* [52] */	"",
		/* [53] */	"To reduce the printed document by 4% to correct for possible distortions in graphic "
						"images, click this box.",
		/* [54] */	"To reduce the printed document by 4% to correct for distortions in graphic images, "
						"click this box.  Not available because the application program you are using "
						"makes this correction automatically.",
		/* [55] */	"When this box is checked, the printed document is reduced by 4% to correct for "
						"possible distortions in graphic images.",
		/* [56] */	"",
		/* [57] */	"To print your document at one-fourth its actual size, click this button.",
		/* [58] */	"To print your document at one-fourth its actual size, click this button.  Not available "
						"because the application program you are using always prints images at actual size.",
		/* [59] */	"When this button is selected, your document is printed at one-fourth its actual size.",
		/* [60] */	""
	}
};


// This 'STR#' resource contains the help strings that are referenced in the 'hdlg' resource
// that corresponds to the PrJobDialog.


resource 'STR#' (gxJobDialogResID, purgeable, sysheap)
{
	{
		/* [1] */	"Missing enabled item in hdlg -8191",
		/* [2] */	"Missing disabled item in hdlg -8191",
		/* [3] */	"Missing checked item in hdlg -8191",
		/* [4] */	"Missing other item in hdlg -8191",
		/* [5] */	"To start printing using the settings in this box, click this button (or press the Return or Enter key).",
		/* [6] */	"",
		/* [7] */	"",
		/* [8] */	"",
		/* [9] */	"To cancel printing without saving any changes you made to settings in this box, click this button.",
		/* [10] */	"",
		/* [11] */	"",
		/* [12] */	"",
		/* [13] */	"",
		/* [14] */	"Type the number of copies to be printed here.",
		/* [15] */	"",
		/* [16] */	"",
		/* [17] */	"To print all the pages in the document, click this button.",
		/* [18] */	"",
		/* [19] */	"When this button is selected, all the pages in the document are printed.",
		/* [20] */	"",
		/* [21] */	"To print a specified range of pages, click this button and type the page numbers"
						" in the boxes to the right.  To print one page, type its number in both boxes.",
		/* [22] */	"",
		/* [23] */	"When this button is selected, only the pages specified in the boxes to the right are printed.",
		/* [24] */	"",
		/* [25] */	"To specify a range of pages to be printed, type the number of the first page here.",
		/* [26] */	"",
		/* [27] */	"",
		/* [28] */	"",
		/* [29] */	"To specify a range of pages to be printed, type the number of the last page here.",
		/* [30] */	"",
		/* [31] */	"",
		/* [32] */	"",
		/* [33] */	"To print on paper automatically fed into the printer from the paper cassette, click this button.",
		/* [34] */	"",
		/* [35] */	"When this button is selected, the printer uses paper automatically fed from the paper cassette.",
		/* [36] */	"",
		/* [37] */	"To print on paper in the multipurpose tray, click this button.",
		/* [38] */	"",
		/* [39] */	"When this button is selected, the printer uses paper in the multipurpose tray.",
		/* [40] */	""
	}
};

